Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
- type ClusterServiceBrokerExpansion
- type ClusterServiceBrokerInterface
- type ClusterServiceBrokersGetter
- type ClusterServiceClassExpansion
- type ClusterServiceClassInterface
- type ClusterServiceClassesGetter
- type ClusterServicePlanExpansion
- type ClusterServicePlanInterface
- type ClusterServicePlansGetter
- type ServiceBindingExpansion
- type ServiceBindingInterface
- type ServiceBindingsGetter
- type ServiceInstanceExpansion
- type ServiceInstanceInterface
- type ServiceInstancesGetter
- type ServicecatalogV1beta1Client
- func (c *ServicecatalogV1beta1Client) ClusterServiceBrokers() ClusterServiceBrokerInterface
- func (c *ServicecatalogV1beta1Client) ClusterServiceClasses() ClusterServiceClassInterface
- func (c *ServicecatalogV1beta1Client) ClusterServicePlans() ClusterServicePlanInterface
- func (c *ServicecatalogV1beta1Client) RESTClient() rest.Interface
- func (c *ServicecatalogV1beta1Client) ServiceBindings(namespace string) ServiceBindingInterface
- func (c *ServicecatalogV1beta1Client) ServiceInstances(namespace string) ServiceInstanceInterface
- type ServicecatalogV1beta1Interface
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ClusterServiceBrokerExpansion ¶
type ClusterServiceBrokerExpansion interface{}
type ClusterServiceBrokerInterface ¶
type ClusterServiceBrokerInterface interface {
Create(*v1beta1.ClusterServiceBroker) (*v1beta1.ClusterServiceBroker, error)
Update(*v1beta1.ClusterServiceBroker) (*v1beta1.ClusterServiceBroker, error)
UpdateStatus(*v1beta1.ClusterServiceBroker) (*v1beta1.ClusterServiceBroker, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1beta1.ClusterServiceBroker, error)
List(opts v1.ListOptions) (*v1beta1.ClusterServiceBrokerList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1beta1.ClusterServiceBroker, err error)
ClusterServiceBrokerExpansion
}
ClusterServiceBrokerInterface has methods to work with ClusterServiceBroker resources.
type ClusterServiceBrokersGetter ¶
type ClusterServiceBrokersGetter interface {
ClusterServiceBrokers() ClusterServiceBrokerInterface
}
ClusterServiceBrokersGetter has a method to return a ClusterServiceBrokerInterface. A group's client should implement this interface.
type ClusterServiceClassExpansion ¶
type ClusterServiceClassExpansion interface{}
type ClusterServiceClassInterface ¶
type ClusterServiceClassInterface interface {
Create(*v1beta1.ClusterServiceClass) (*v1beta1.ClusterServiceClass, error)
Update(*v1beta1.ClusterServiceClass) (*v1beta1.ClusterServiceClass, error)
UpdateStatus(*v1beta1.ClusterServiceClass) (*v1beta1.ClusterServiceClass, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1beta1.ClusterServiceClass, error)
List(opts v1.ListOptions) (*v1beta1.ClusterServiceClassList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1beta1.ClusterServiceClass, err error)
ClusterServiceClassExpansion
}
ClusterServiceClassInterface has methods to work with ClusterServiceClass resources.
type ClusterServiceClassesGetter ¶
type ClusterServiceClassesGetter interface {
ClusterServiceClasses() ClusterServiceClassInterface
}
ClusterServiceClassesGetter has a method to return a ClusterServiceClassInterface. A group's client should implement this interface.
type ClusterServicePlanExpansion ¶
type ClusterServicePlanExpansion interface{}
type ClusterServicePlanInterface ¶
type ClusterServicePlanInterface interface {
Create(*v1beta1.ClusterServicePlan) (*v1beta1.ClusterServicePlan, error)
Update(*v1beta1.ClusterServicePlan) (*v1beta1.ClusterServicePlan, error)
UpdateStatus(*v1beta1.ClusterServicePlan) (*v1beta1.ClusterServicePlan, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1beta1.ClusterServicePlan, error)
List(opts v1.ListOptions) (*v1beta1.ClusterServicePlanList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1beta1.ClusterServicePlan, err error)
ClusterServicePlanExpansion
}
ClusterServicePlanInterface has methods to work with ClusterServicePlan resources.
type ClusterServicePlansGetter ¶
type ClusterServicePlansGetter interface {
ClusterServicePlans() ClusterServicePlanInterface
}
ClusterServicePlansGetter has a method to return a ClusterServicePlanInterface. A group's client should implement this interface.
type ServiceBindingExpansion ¶
type ServiceBindingExpansion interface{}
type ServiceBindingInterface ¶
type ServiceBindingInterface interface {
Create(*v1beta1.ServiceBinding) (*v1beta1.ServiceBinding, error)
Update(*v1beta1.ServiceBinding) (*v1beta1.ServiceBinding, error)
UpdateStatus(*v1beta1.ServiceBinding) (*v1beta1.ServiceBinding, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1beta1.ServiceBinding, error)
List(opts v1.ListOptions) (*v1beta1.ServiceBindingList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1beta1.ServiceBinding, err error)
ServiceBindingExpansion
}
ServiceBindingInterface has methods to work with ServiceBinding resources.
type ServiceBindingsGetter ¶
type ServiceBindingsGetter interface {
ServiceBindings(namespace string) ServiceBindingInterface
}
ServiceBindingsGetter has a method to return a ServiceBindingInterface. A group's client should implement this interface.
type ServiceInstanceExpansion ¶
type ServiceInstanceExpansion interface {
UpdateReferences(serviceInstance *v1beta1.ServiceInstance) (*v1beta1.ServiceInstance, error)
}
The ReferencesExtension interface allows setting the References to ServiceClasses and ServicePlans.
type ServiceInstanceInterface ¶
type ServiceInstanceInterface interface {
Create(*v1beta1.ServiceInstance) (*v1beta1.ServiceInstance, error)
Update(*v1beta1.ServiceInstance) (*v1beta1.ServiceInstance, error)
UpdateStatus(*v1beta1.ServiceInstance) (*v1beta1.ServiceInstance, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1beta1.ServiceInstance, error)
List(opts v1.ListOptions) (*v1beta1.ServiceInstanceList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1beta1.ServiceInstance, err error)
ServiceInstanceExpansion
}
ServiceInstanceInterface has methods to work with ServiceInstance resources.
type ServiceInstancesGetter ¶
type ServiceInstancesGetter interface {
ServiceInstances(namespace string) ServiceInstanceInterface
}
ServiceInstancesGetter has a method to return a ServiceInstanceInterface. A group's client should implement this interface.
type ServicecatalogV1beta1Client ¶
type ServicecatalogV1beta1Client struct {
// contains filtered or unexported fields
}
ServicecatalogV1beta1Client is used to interact with features provided by the servicecatalog.k8s.io group.
func New ¶
func New(c rest.Interface) *ServicecatalogV1beta1Client
New creates a new ServicecatalogV1beta1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*ServicecatalogV1beta1Client, error)
NewForConfig creates a new ServicecatalogV1beta1Client for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *ServicecatalogV1beta1Client
NewForConfigOrDie creates a new ServicecatalogV1beta1Client for the given config and panics if there is an error in the config.
func (*ServicecatalogV1beta1Client) ClusterServiceBrokers ¶
func (c *ServicecatalogV1beta1Client) ClusterServiceBrokers() ClusterServiceBrokerInterface
func (*ServicecatalogV1beta1Client) ClusterServiceClasses ¶
func (c *ServicecatalogV1beta1Client) ClusterServiceClasses() ClusterServiceClassInterface
func (*ServicecatalogV1beta1Client) ClusterServicePlans ¶
func (c *ServicecatalogV1beta1Client) ClusterServicePlans() ClusterServicePlanInterface
func (*ServicecatalogV1beta1Client) RESTClient ¶
func (c *ServicecatalogV1beta1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*ServicecatalogV1beta1Client) ServiceBindings ¶
func (c *ServicecatalogV1beta1Client) ServiceBindings(namespace string) ServiceBindingInterface
func (*ServicecatalogV1beta1Client) ServiceInstances ¶
func (c *ServicecatalogV1beta1Client) ServiceInstances(namespace string) ServiceInstanceInterface
type ServicecatalogV1beta1Interface ¶
type ServicecatalogV1beta1Interface interface {
RESTClient() rest.Interface
ClusterServiceBrokersGetter
ClusterServiceClassesGetter
ClusterServicePlansGetter
ServiceBindingsGetter
ServiceInstancesGetter
}